@@ -1,15 +1,18 @@
 from __future__ import annotations
 
+from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
 import hikari
-from attr import define
 from hikari import Locale, Member, PartialInteraction, Snowflake, User
 
 if TYPE_CHECKING:
+    from asyncio import Future
     from typing import Any, Sequence, Type, TypeVar
 
-    from crescent.bot import Mixin
+    from hikari.api import InteractionResponseBuilder
+
+    from crescent.client import Client, GatewayTraits, RESTTraits
 
     ContextT = TypeVar("ContextT", bound="BaseContext")
 
@@ -17,14 +20,40 @@ if TYPE_CHECKING:
 __all__: Sequence[str] = ("BaseContext",)
 
 
-@define(slots=True)
+@dataclass
 class BaseContext:
     """Represents the context for interactions"""
 
+    __slots__ = (
+        "interaction",
+        "app",
+        "client",
+        "application_id",
+        "type",
+        "token",
+        "id",
+        "version",
+        "channel_id",
+        "guild_id",
+        "user",
+        "member",
+        "locale",
+        "command",
+        "command_type",
+        "group",
+        "sub_group",
+        "options",
+        "_has_created_message",
+        "_has_deferred_response",
+        "_rest_interaction_future",
+    )
+
     interaction: PartialInteraction
     """The interaction object."""
-    app: Mixin
+    app: GatewayTraits | RESTTraits
     """The application instance."""
+    client: Client
+    """The crescent Client instance."""
     application_id: Snowflake
     """The ID for the client that this interaction belongs to."""
     type: int
@@ -70,6 +99,18 @@ class BaseContext:
     deferring an interaction response.
     """
 
+    _rest_interaction_future: Future[InteractionResponseBuilder] | None
+
+    @property
+    def _unset_future(self) -> Future[InteractionResponseBuilder] | None:
+        """Returns the future for the response, if it exists and hasn't already been set.
+
+        Will only exist for RESTBot."""
+
+        if self._rest_interaction_future and not self._rest_interaction_future.done():
+            return self._rest_interaction_future
+        return None
+
     def into(self, context_t: Type[ContextT]) -> ContextT:
         """Convert to a context of a different type."""
         if type(self) is context_t:
@@ -79,6 +120,7 @@ class BaseContext:
         return context_t(
             interaction=self.interaction,
             app=self.app,
+            client=self.client,
             application_id=self.application_id,
             type=self.type,
             token=self.token,
@@ -94,7 +136,7 @@ class BaseContext:
             group=self.group,
             sub_group=self.sub_group,
             options=self.options,
-            # Pyright expects these arguments to start with an underscore but attrs removes that.
-            has_created_message=self._has_created_message,  # pyright: ignore
-            has_deferred_response=self._has_deferred_response,  # pyright: ignore
+            _has_created_message=self._has_created_message,
+            _has_deferred_response=self._has_deferred_response,
+            _rest_interaction_future=self._rest_interaction_future,
         )
