@@ -5,5 +5,6 @@ from typing import Sequence
 from crescent.utils.any_issubclass import *
 from crescent.utils.gather_iter import *
 from crescent.utils.options import *
+from crescent.utils.tasks import *
 
-__all__: Sequence[str] = ("any_issubclass", "gather_iter", "unwrap", "map_or")
+__all__: Sequence[str] = ("any_issubclass", "gather_iter", "unwrap", "map_or", "create_task")
